@@ -143,7 +143,7 @@ class UTFStringIO(StringIO):
 
     def write(self, s):
         if isinstance(s, bytes):
-            s = s.decode('utf-8')
+            s = s.decode('utf-8', errors='replace')
         return StringIO.write(self, s)
 
 
